@@ -134,9 +134,10 @@ impl Client {
         // Let's fetch the Register from the network
         let query = DataQuery::Register(RegisterRead::Get(address));
         let query_result = self.send_query(query).await?;
-        let msg_id = query_result.msg_id;
         match query_result.response {
-            QueryResponse::GetRegister(res) => res.map_err(|err| Error::from((err, msg_id))),
+            QueryResponse::GetRegister((res, op_id)) => {
+                res.map_err(|err| Error::ErrorMessage { source: err, op_id })
+            }
             _ => Err(Error::ReceivedUnexpectedEvent),
         }
     }
@@ -233,7 +234,7 @@ mod tests {
     };
     use crate::{
         client::{
-            utils::test_utils::{create_test_client, gen_ed_keypair, run_w_backoff},
+            utils::test_utils::{create_test_client, gen_ed_keypair, run_w_backoff_delayed},
             Error,
         },
         url::Url,
@@ -269,7 +270,7 @@ mod tests {
             let now = Instant::now();
 
             // write to the register
-            let _value1_hash = run_w_backoff(
+            let _value1_hash = run_w_backoff_delayed(
                 || client.write_to_register(address, value_1.clone(), BTreeSet::new()),
                 10,
             )
@@ -302,7 +303,7 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
 
         assert!(register.is_private());
         assert_eq!(*register.name(), name);
@@ -317,7 +318,7 @@ mod tests {
             .store_public_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
 
         assert!(register.is_public());
         assert_eq!(*register.name(), name);
@@ -340,11 +341,11 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
 
         assert_eq!(register.size(None)?, 0);
 
-        let permissions = run_w_backoff(
+        let permissions = run_w_backoff_delayed(
             || client.get_register_permissions_for_user(address, owner),
             10,
         )
@@ -382,7 +383,7 @@ mod tests {
             .store_public_register(name, tag, owner, perms)
             .await?;
 
-        let permissions = run_w_backoff(
+        let permissions = run_w_backoff_delayed(
             || client.get_register_permissions_for_user(address, owner),
             10,
         )
@@ -426,7 +427,7 @@ mod tests {
         let value_1 = random_url()?;
 
         // write to the register
-        let value1_hash = run_w_backoff(
+        let value1_hash = run_w_backoff_delayed(
             || client.write_to_register(address, value_1.clone(), BTreeSet::new()),
             10,
         )
@@ -442,7 +443,7 @@ mod tests {
         let value_2 = random_url()?;
 
         // write to the register
-        let value2_hash = run_w_backoff(
+        let value2_hash = run_w_backoff_delayed(
             || client.write_to_register(address, value_2.clone(), BTreeSet::new()),
             10,
         )
@@ -456,10 +457,12 @@ mod tests {
         assert_eq!(2, hashes.len());
 
         // get_register_entry
-        let retrieved_value_1 = client.get_register_entry(address, value1_hash).await?;
+        let retrieved_value_1 =
+            run_w_backoff_delayed(|| client.get_register_entry(address, value1_hash), 10).await?;
         assert_eq!(retrieved_value_1, value_1);
 
-        let retrieved_value_2 = client.get_register_entry(address, value2_hash).await?;
+        let retrieved_value_2 =
+            run_w_backoff_delayed(|| client.get_register_entry(address, value2_hash), 10).await?;
         assert_eq!(retrieved_value_2, value_2);
 
         // Requesting a hash which desn't exist throws an error
@@ -488,7 +491,8 @@ mod tests {
             .await?;
 
         // Assert that the data is stored.
-        let current_owner = run_w_backoff(|| client.get_register_owner(address), 10).await?;
+        let current_owner =
+            run_w_backoff_delayed(|| client.get_register_owner(address), 10).await?;
 
         assert_eq!(owner, current_owner);
 
@@ -509,7 +513,7 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
 
         assert!(register.is_private());
 
@@ -525,7 +529,7 @@ mod tests {
         match res {
             Err(Error::NoResponse) => Ok(()),
             Err(err) => Err(eyre!(
-                "Unexpected error returned when deleting a nonexisting Private Register: {}",
+                "Unexpected error returned when deleting a nonexisting Private Register: {:?}",
                 err
             )),
             Ok(_data) => Err(eyre!("Unexpectedly retrieved a deleted Private Register!",)),
@@ -547,7 +551,7 @@ mod tests {
             .store_public_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
         assert!(register.is_public());
 
         match client.delete_register(address).await {
@@ -556,7 +560,7 @@ mod tests {
                 ..
             }) => {}
             Err(err) => bail!(
-                "Unexpected error returned when attempting to delete a Public Register: {}",
+                "Unexpected error returned when attempting to delete a Public Register: {:?}",
                 err
             ),
             Ok(()) => {}
