@@ -1,9 +1,10 @@
 use super::{
-    node::{KeyedSig, SigShare},
+    system::{KeyedSig, SigShare},
     Error, Result,
 };
 use crate::{
-    routing::{AggregatorError, SectionKeyShare, SignatureAggregator},
+    messaging::signature_aggregator::{Error as AggregatorError, SignatureAggregator},
+    routing::SectionKeyShare,
     types::{PublicKey, Signature},
 };
 use bls::PublicKey as BlsPublicKey;
@@ -11,6 +12,8 @@ use ed25519_dalek::{
     Keypair as EdKeypair, PublicKey as EdPublicKey, Signature as EdSignature, Signer as _,
     Verifier as _,
 };
+use std::sync::Arc;
+use tokio::sync::RwLock;
 use xor_name::XorName;
 
 /// Authority of a network peer.
@@ -95,11 +98,12 @@ pub struct SectionAuth {
 
 impl SectionAuth {
     /// Try to construct verified section authority by aggregating a new share.
-    pub(crate) fn try_authorize(
-        aggregator: &mut SignatureAggregator,
+    pub(crate) async fn try_authorize(
+        aggregator: Arc<RwLock<SignatureAggregator>>,
         share: BlsShareAuth,
         payload: impl AsRef<[u8]>,
     ) -> Result<AuthorityProof<Self>, AggregatorError> {
+        let mut aggregator = aggregator.write().await;
         let sig = aggregator.add(payload.as_ref(), share.sig_share.clone())?;
 
         if share.sig_share.public_key_set.public_key() != sig.public_key {
@@ -125,7 +129,7 @@ impl SectionAuth {
 ///
 /// Validation is defined by the [`VerifyAuthority`] impl for `T`.
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub struct AuthorityProof<T>(T);
+pub struct AuthorityProof<T>(pub(crate) T);
 
 impl<T: VerifyAuthority> AuthorityProof<T> {
     /// Verify the authority of `inner`.
