@@ -6,25 +6,32 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{delivery_group, Comm, Core};
+use super::{
+    delivery_group, split_barrier::SplitBarrier, Comm, Core, SignatureAggregator, KEY_CACHE_SIZE,
+    RESOURCE_PROOF_DATA_SIZE, RESOURCE_PROOF_DIFFICULTY,
+};
 use crate::dbs::UsedSpace;
 use crate::messaging::{
-    node::{Network, NodeState, Peer, Proposal, Section},
-    EndUser, MessageId, SectionAuthorityProvider, SocketId, WireMsg,
+    system::{NodeState, Peer, Proposal, Section},
+    MessageId, SectionAuthorityProvider, WireMsg,
 };
+use crate::prefix_map::NetworkPrefixMap;
 use crate::routing::{
+    dkg::{DkgVoter, ProposalAggregator},
     error::Result,
-    network::NetworkUtils,
     node::Node,
-    peer::PeerUtils,
     routing_api::command::Command,
-    section::{NodeStateUtils, SectionKeyShare, SectionUtils},
+    section::{
+        ElderCandidatesUtils, NodeStateUtils, SectionKeyShare, SectionKeysProvider, SectionUtils,
+    },
     Error, Event,
 };
+use resource_proof::ResourceProof;
 use secured_linked_list::SecuredLinkedList;
 use std::net::SocketAddr;
 use std::path::PathBuf;
-use tokio::sync::mpsc;
+use std::sync::Arc;
+use tokio::sync::{mpsc, RwLock};
 use xor_name::XorName;
 
 impl Core {
@@ -51,29 +58,40 @@ impl Core {
         )
     }
 
-    pub(crate) async fn relocated(&self, new_node: Node, new_section: Section) -> Result<Self> {
-        Self::new(
-            self.comm.clone(),
-            new_node,
-            new_section,
-            None,
-            self.event_tx.clone(),
-            self.used_space.clone(),
-            self.root_storage_dir.clone(),
-        )
-    }
+    pub(crate) async fn relocated(&self, mut new_node: Node, new_section: Section) -> Result<Self> {
+        let section_keys_provider = SectionKeysProvider::new(KEY_CACHE_SIZE, None);
 
-    pub(crate) fn get_enduser_by_addr(&self, sender: &SocketAddr) -> Option<&EndUser> {
-        self.end_users.get_enduser_by_addr(sender)
-    }
+        // make sure the new Node has the correct local addr as Comm
+        let comm = self.comm.clone();
+        new_node.addr = comm.our_connection_info();
 
-    pub(crate) fn get_socket_addr(&self, id: SocketId) -> Option<&SocketAddr> {
-        self.end_users.get_socket_addr(id)
-    }
+        let network = NetworkPrefixMap::new(*new_section.genesis_key());
+        // TODO: to keep our knowledge of the network and avoid unnecessary AE msgs:
+        // - clone self.network instead,
+        // - remove the SAP of our new section from the cloned network
+        // - and add current section's SAP to the cloned network
 
-    pub(crate) fn try_add_enduser(&mut self, sender: SocketAddr) -> Result<EndUser> {
-        let section_prefix = self.section.prefix();
-        self.end_users.try_add(sender, section_prefix)
+        Ok(Self {
+            comm,
+            node: new_node,
+            section: new_section,
+            network,
+            section_keys_provider,
+            proposal_aggregator: ProposalAggregator::default(),
+            split_barrier: SplitBarrier::new(),
+            message_aggregator: Arc::new(RwLock::new(SignatureAggregator::default())),
+            dkg_voter: DkgVoter::default(),
+            relocate_state: None,
+            event_tx: self.event_tx.clone(),
+            joins_allowed: true,
+            resource_proof: ResourceProof::new(RESOURCE_PROOF_DATA_SIZE, RESOURCE_PROOF_DIFFICULTY),
+            register_storage: self.register_storage.clone(),
+            root_storage_dir: self.root_storage_dir.clone(),
+            used_space: self.used_space.clone(),
+            capacity: self.capacity.clone(),
+            chunk_storage: self.chunk_storage.clone(),
+            liveness: self.liveness.clone(),
+        })
     }
 
     pub(crate) fn node(&self) -> &Node {
@@ -88,10 +106,6 @@ impl Core {
         self.section.chain()
     }
 
-    pub(crate) fn network(&self) -> &Network {
-        &self.network
-    }
-
     /// Is this node an elder?
     pub(crate) fn is_elder(&self) -> bool {
         self.section.is_elder(&self.node.name())
@@ -161,8 +175,8 @@ impl Core {
             .handle_timeout(&self.node, token, *self.section_chain().last_key())
     }
 
-    // Send message over the network.
-    pub(crate) async fn relay_message(&self, mut wire_msg: WireMsg) -> Result<Command> {
+    // Send message to peers on the network.
+    pub(crate) fn send_msg_to_peers(&self, mut wire_msg: WireMsg) -> Result<Command> {
         let dst_location = wire_msg.dst_location();
         let (targets, dg_size) = delivery_group::delivery_targets(
             dst_location,
@@ -214,13 +228,8 @@ impl Core {
     pub(crate) fn set_joins_allowed(&self, joins_allowed: bool) -> Result<Vec<Command>> {
         let mut commands = Vec::new();
         if self.is_elder() && joins_allowed != self.joins_allowed {
-            let active_members: Vec<XorName> = self
-                .section
-                .active_members()
-                .map(|peer| *peer.name())
-                .collect();
-            let msg_id = MessageId::from_content(&active_members)?;
-            commands.extend(self.propose(Proposal::JoinsAllowed((msg_id, joins_allowed)))?);
+            commands
+                .extend(self.propose(Proposal::JoinsAllowed((MessageId::new(), joins_allowed)))?);
         }
         Ok(commands)
     }
@@ -230,8 +239,10 @@ impl Core {
     pub(crate) fn promote_and_demote_elders(&mut self) -> Result<Vec<Command>> {
         let mut commands = vec![];
 
-        for info in self.section.promote_and_demote_elders(&self.node.name()) {
-            commands.extend(self.send_dkg_start(info)?);
+        for elder_candidates in self.section.promote_and_demote_elders(&self.node.name()) {
+            // Send DKG start to all candidates
+            let recipients: Vec<_> = elder_candidates.peers().collect();
+            commands.extend(self.send_dkg_start(elder_candidates, &recipients)?);
         }
 
         Ok(commands)
