@@ -34,12 +34,7 @@ impl Core {
         section_signed: KeyedSig,
         proof_chain: SecuredLinkedList,
         members: Option<SectionPeers>,
-        sender: SocketAddr,
     ) -> Result<Vec<Command>> {
-        info!(
-            "Anti-Entropy: section update message received from peer: {}",
-            sender
-        );
         let snapshot = self.state_snapshot();
 
         let signed_section_auth = SectionAuth {
@@ -58,11 +53,18 @@ impl Core {
                         "Anti-Entropy: updated remote section SAP updated for {:?}",
                         section_auth.prefix
                     );
+                    self.section
+                        .merge_chain(&signed_section_auth, proof_chain)?;
+                    self.section.merge_members(members)?;
                 } else {
                     debug!(
                         "Anti-Entropy: discarded SAP for {:?} since it's the same as the one in our records: {:?}",
                         section_auth.prefix, section_auth
                     );
+
+                    self.section.merge_members(members)?;
+
+                    // Ok(vec![])
                 }
             }
             Err(err) => {
@@ -74,9 +76,10 @@ impl Core {
             }
         }
 
-        // TODO: when do we want to do all the things that were done on aync? Will all AE?
+        self.fire_node_event_for_any_new_adults().await?;
 
-        self.update_section(&signed_section_auth, snapshot, proof_chain, members)
+        // always run this, only changes will trigger events
+        self.update_for_new_node_state_and_fire_events(snapshot)
             .await
     }
     pub(crate) async fn handle_anti_entropy_retry_msg(
